*********************************************************
****************** Clean and Encode *********************
*********************************************************

* Settings
clear
set more off
set mem 700m

* Load dataset
use "MergedDataset.dta", clear


***********************
** Initial Variable Construction
***********************

* Create state string var based on package numbers
gen state="" 
replace state="Andhra Pradesh" if substr(package,1,2) == "AP"
replace state="Arunachal Pradesh" if substr(package,1,2) == "AR"
replace state="Assam" if substr(package,1,2) == "AS"
replace state="Bihar" if substr(package,1,2) == "BR"
replace state="Chhattisgarh" if substr(package,1,2) == "CG"
replace state="Goa" if substr(package,1,2) == "GA"
replace state="Gujarat" if substr(package,1,2) == "GJ"
replace state="Haryana" if substr(package,1,2) == "HR"
replace state="Himachal Pradesh" if substr(package,1,2) == "HP"
replace state="Jammu And Kashmir" if substr(package,1,2) == "JK"
replace state="Jharkhand" if substr(package,1,2) == "JH"
replace state="Karnataka" if substr(package,1,2) == "KN"
replace state="Kerala" if substr(package,1,2) == "KR" 
replace state="Madhya Pradesh" if substr(package,1,2) == "MP"
replace state="Maharashtra" if substr(package,1,2) == "MH" 
replace state="Manipur" if substr(package,1,2) == "MN" 
replace state="Meghalaya" if substr(package,1,2) == "MG"
replace state="Mizoram" if substr(package,1,2) == "MZ"
replace state="Nagaland" if substr(package,1,2) == "NG"
replace state="Orissa" if substr(package,1,2) == "OR" | substr(package,1,2) == "0R" 
replace state="Punjab" if substr(package,1,2) == "PB"
replace state="Rajasthan" if substr(package,1,2) == "RJ"
replace state="Sikkim" if substr(package,1,2) == "SK"
replace state="Tamilnadu" if substr(package,1,2) == "TN"
replace state="Tripura" if substr(package,1,2) == "TR"
replace state="Uttar Pradesh" if substr(package,1,2) == "UP"
replace state="Uttarakhand" if substr(package,1,2) == "UT"
replace state="West Bengal" if substr(package,1,2) == "WB"

* Guess state based on districts
bysort district: egen mode_state = mode(state)
gen different = (state != mode_state & !mi(state))
by district: egen varies = max(different)
replace state = mode_state if !varies
drop mode_state different varies

* Standardize sanction years and destring
replace sanction_year = substr(sanction_year, 1, 4)
destring sanction_year, replace

* Create NIT year variable
gen nit_year = year(nit_date)

* Number contracts within packages
bysort sanction_year package district: gen contracts_in_package = _N
bysort sanction_year package district (contract_date): gen contract_number = _n


***********************
** Cleaning
***********************

* Drop unused variables
drop cleared_road_count estimated_cost_less_protect prep_work_length ///
	earch_work_length subbase_length base_course_length surface_course_length road_signs_count cd_works misc clearance_date final_bill_date ///
	joint_WB joint_ADB joint_PMGSY habitations_covered_count est_subcost cd_works_count cd_works_est_cost ///
	ls_bridges_count ls_bridges_est_cost protection_works_est_cost other_works_est_cost est_state_contribution

* Drop these variables, as they are not needed
drop nit_number* agreement_number* bidding_package

* Drop if state is missing or if sanction year and nit_date are both missing since these obs cannot be used in analysis
drop if mi(state) | ( mi(sanction_year) & mi(nit_date) )

* Drop if nit_year and sanction_year are impossible as this prohibits analysis
drop if nit_year < sanction_year & !mi(sanction_year)

* Clean up company names
replace company = "" if company == "0" | company == "--"

* Mark missing if estimated cost is 0 (0 is impossible)
replace estimated_cost = . if estimated_cost == 0

* Mark missing if estimated cost per km is 0 (0 is impossible)
replace est_cost_per_km = . if est_cost_per_km == 0

* Mark missing if road length is 0 (0 is impossible) or very low 
replace road_length = . if road_length == 0
replace road_length = . if road_length < .1

* Mark missing a few odd road lengths
replace road_length = . if road_length / sanctioned_road_count < .5 & estimated_cost / road_length > 50 & !mi(estimated_cost / road_length)

* Attempt to correct for extreme contract values
replace contract_value = contract_value / 100000 if contract_value > 1000 & estimated_cost / (contract_value / 100000) < 10 
replace contract_value = . if estimated_cost / contract_value < .5 & payment / contract_value < .5 
replace contract_value = . if contract_value / estimated_cost < .2 & contracts_in_package == 1

* Remove impossible bidding values
gen mark = (qualified_bids > total_bids)
replace total_bids = . if mark
replace qualified_bids = . if mark
drop mark

* Remove impossible completion dates and refresh days late variable
gen days_late = actualcompletion_date - completiondue_date
gen contract_complete = !mi(actualcompletion_date)
gen completion_period = completiondue_date - contract_date
replace completiondue_date = . if completiondue_date > date("1Jan2012", "DMY")
replace actualcompletion_date = . if actualcompletion_date > date("1Jun2009", "DMY")
replace completiondue_date = . if completiondue_date < contract_date + 30 & !mi(contract_date)
replace actualcompletion_date = . if actualcompletion_date < contract_date + 30 & !mi(contract_date)
replace completiondue_date = . if completion_period > 400 & days_late < -180 & !mi(completion_period)
replace actualcompletion_date = . if days_late > 365 & roads_completed_late == 0 & !mi(days_late)
replace days_late = actualcompletion_date - completiondue_date
replace contract_complete = !mi(actualcompletion_date)
replace completion_period = completiondue_date - contract_date
gen full_project_period = actualcompletion_date - nit_date
replace full_project_period = . if full_project_period < 0
replace full_project_period = . if nit_date > completiondue_date
replace full_project_period = . if actualcompletion_date < contract_date


* Remove impossible contact date / sanction year combinations
gen tag = (year(contract_date) < sanction_year)
replace contract_date = . if tag
replace sanction_year = . if tag
drop tag

* For observations that appear to be the same contract with different contract values, set the contract value to missing and get rid of the duplicate
duplicates tag package district sanction_year nit_date contractor contract_date agreement_date company completiondue_date, g(dup)
replace contract_value = . if dup > 0
drop dup
duplicates drop

* Drop duplicate observations for the same contract, keeping the one with the newest contract_date, newest agreement date, non-missing company, or newest completion due date
gsort package district sanction_year nit_date contractor_id contract_value -contract_date -agreement_date -company -completiondue_date -actualcompletion_date ///
	quality_grade1 quality_grade2 quality_grade3 quality_grade4 quality_grade5 quality_grade6 quality_grade7 quality_grade8 quality_grade9 quality_grade10 ///
	quality_grade11 quality_grade12 quality_grade13 quality_grade14 quality_grade15 quality_grade16 quality_grade17 quality_grade18 quality_grade19 quality_grade20 ///
	quality_grade21 quality_grade22 quality_grade23 quality_grade24 quality_grade25 ///
	inspection_date1 inspection_date2 inspection_date3 inspection_date4 inspection_date5 inspection_date6 inspection_date7 inspection_date8 inspection_date9 inspection_date10 ///
	inspection_date11 inspection_date12 inspection_date13 inspection_date14 inspection_date15 inspection_date16 inspection_date17 inspection_date18 inspection_date19 inspection_date20 ///
	inspection_date21 inspection_date22 inspection_date23 inspection_date24 inspection_date25 ///
	estimated_cost payment
duplicates drop package district sanction_year nit_date contractor_id contract_value, force

* Standardize package and district names
replace package = upper(package)
replace district = proper(district)

* Drop full duplicates
duplicates drop


***********************
** Variable Construction and Labeling
***********************

* Create numerical state ID
encode state, generate (state_id)

* Create numerical state-district ID
gen state_dist = district + state
encode state_dist if !mi(district), g(district_id)
drop state_dist

* Create numerical state-NIT year and state-sanction IDs (for FEs)
egen state_nyear_id = group(state_id nit_year)
egen state_syear_id = group(state_id sanction_year)

* Mark packages that were awarded during eproc
gen eproc_old = .
replace eproc_old = 0 if state == "Andhra Pradesh"
replace eproc_old = 1 if state == "Andhra Pradesh" & nit_date >= date("24Mar2004", "DMY")
replace eproc_old = 0 if state == "Arunachal Pradesh"
replace eproc_old = 0 if state == "Assam"
replace eproc_old = 1 if state == "Assam" & nit_date >= date("1Aug2004", "DMY")
replace eproc_old = 0 if state == "Bihar"
replace eproc_old = 0 if state == "Chhattisgarh"
replace eproc_old = 1 if state == "Chhattisgarh" & nit_date >= date("10Mar2006", "DMY") & estimated_cost > 50
replace eproc_old = 1 if state == "Chhattisgarh" & nit_date >= date("31Oct2006", "DMY") & estimated_cost > 50
replace eproc_old = 1 if state == "Chhattisgarh" & nit_date >= date("15Mar2007", "DMY") & estimated_cost > 50
replace eproc_old = 0 if state == "Gujarat"
replace eproc_old = 1 if state == "Gujarat" & ((nit_date >= date("22Nov2006", "DMY") & estimated_cost > 50) | (nit_date >= date("15Feb2007", "DMY") & estimated_cost > 25) | (nit_date >= date("2Jun2007", "DMY") & estimated_cost > 10))
replace eproc_old = 0 if state == "Haryana"
replace eproc_old = 1 if state == "Haryana" & nit_date >= date("1Sep2007", "DMY")
replace eproc_old = 0 if state == "Himachal Pradesh"
replace eproc_old = 0 if state == "Jharkhand"
replace eproc_old = 0 if state == "Karnataka" 
replace eproc_old = 1 if state == "Karnataka" & nit_date >= date("1Jul2008", "DMY")
replace eproc_old = 0 if state == "Kerala"
replace eproc_old = 0 if state == "Madhya Pradesh"
replace eproc_old = 1 if state == "Madhya Pradesh" & nit_date >= date("1Mar2007", "DMY")
replace eproc_old = 0 if state == "Maharashtra"
replace eproc_old = 0 if state == "Manipur"
replace eproc_old = 0 if state == "Orissa"
replace eproc_old = 1 if state == "Orissa" & ((nit_date >= date("1Jun2008", "DMY") & estimated_cost > 100) | (nit_date >= date("1Mar2009", "DMY") & estimated_cost > 10))
replace eproc_old = 0 if state == "Punjab" 
replace eproc_old = 0 if state == "Rajasthan" 
replace eproc_old = 0 if state == "Sikkim" 
replace eproc_old = 0 if state == "Tripura" 
replace eproc_old = 0 if state == "Uttar Pradesh"
replace eproc_old = 0 if state == "West Bengal" 
replace eproc_old = 1 if state == "West Bengal" & nit_date >= date("1Jan2009", "DMY")
replace eproc_old = 1 if state == "West Bengal" & nit_date >= date("1Apr2009", "DMY")
replace eproc_old = . if mi(nit_date)


gen eproc = .
replace eproc = 0 if state == "Andhra Pradesh"
replace eproc = 1 if state == "Andhra Pradesh" & nit_date >= date("24Mar2004", "DMY") // FTPD
replace eproc = 0 if state == "Arunachal Pradesh"
replace eproc = 1 if state == "Arunachal Pradesh" & nit_date >= date("21Jun2011", "DMY") // FTPD
replace eproc = 0 if state == "Assam"
replace eproc = 1 if state == "Assam" & nit_date >= date("1Aug2004", "DMY") // Original
replace eproc = 0 if state == "Bihar"
replace eproc = 1 if state == "Bihar" & nit_date >= date("14Jun2010", "DMY") // FTPD
replace eproc = 0 if state == "Chhattisgarh"
replace eproc = 1 if state == "Chhattisgarh" & nit_date >= date("10Mar2006", "DMY") // Original
replace eproc = 0 if state == "Gujarat"
replace eproc = 1 if state == "Gujarat" & nit_date >= date("22Nov2006", "DMY") // Original
replace eproc = 0 if state == "Haryana"
replace eproc = 1 if state == "Haryana" & nit_date >= date("1Sep2007", "DMY") // Originial
replace eproc = 0 if state == "Himachal Pradesh"
replace eproc = 1 if state == "Himachal Pradesh" & nit_date >= date("17Feb2010", "DMY") // FTPD
replace eproc = 0 if state == "Jammu And Kashmir"
replace eproc = 1 if state == "Jammu And Kashmir" & nit_date >= date("3Feb2011", "DMY") // FTPD
replace eproc = 0 if state == "Jharkhand"
replace eproc = 1 if state == "Jharkhand" & nit_date >= date("26Apr2010", "DMY") // FTPD
replace eproc = 0 if state == "Karnataka" 
replace eproc = 1 if state == "Karnataka" & nit_date >= date("1Jul2008", "DMY") // Original
replace eproc = 0 if state == "Kerala"
replace eproc = 1 if state == "Kerala" & nit_date >= date("14Dec2011", "DMY") // FTPD
replace eproc = 0 if state == "Madhya Pradesh"
replace eproc = 1 if state == "Madhya Pradesh" & nit_date >= date("1Mar2007", "DMY") // Original
replace eproc = 0 if state == "Maharashtra"
replace eproc = 1 if state == "Maharashtra" & nit_date >= date("7Apr2010", "DMY") // FTPD
replace eproc = 0 if state == "Manipur"
replace eproc = 1 if state == "Manipur" & nit_date >= date("28March2010", "DMY") // FTPD
replace eproc = 0 if state == "Meghalaya"
replace eproc = 1 if state == "Meghalaya" & nit_date >= date("20Sept2011", "DMY") // FTPD
replace eproc = 0 if state == "Mizoram"
replace eproc = 1 if state == "Mizoram" & nit_date >= date("2Nov2012", "DMY") // FTPD
replace eproc = 0 if state == "Nagaland"
replace eproc = 1 if state == "Nagaland" & nit_date >= date("15Nov2011", "DMY") // FTPD
replace eproc = 0 if state == "Orissa"
replace eproc = 1 if state == "Orissa" & nit_date >= date("1Jun2008", "DMY") // Original
replace eproc = 0 if state == "Punjab" 
replace eproc = 1 if state == "Punjab" & nit_date >= date("22Jul2011", "DMY") // FTPD
replace eproc = 0 if state == "Rajasthan" 
replace eproc = 1 if state == "Rajasthan" & nit_date >= date("14Dec2009", "DMY") // FTPD
replace eproc = 0 if state == "Sikkim" 
replace eproc = 1 if state == "Sikkim" & nit_date >= date("3Nov2011", "DMY") // FTPD
replace eproc = 0 if state == "Tamilnadu" 
replace eproc = 1 if state == "Tamilnadu" & nit_date >= date("29Mar2013", "DMY") // FTPD
replace eproc = 0 if state == "Tripura" 
replace eproc = 1 if state == "Tripura" & nit_date >= date("5Jul2010", "DMY") // FTPD 
replace eproc = 0 if state == "Uttar Pradesh"
replace eproc = 1 if state == "Uttar Pradesh" & nit_date >= date("25Feb2010", "DMY") // FTPD 
replace eproc = 0 if state == "Uttarakhand"
replace eproc = 1 if state == "Uttarakhand" & nit_date >= date("5May2011", "DMY") // FTPD 
replace eproc = 0 if state == "West Bengal" 
replace eproc = 1 if state == "West Bengal" & nit_date >= date("1Jan2009", "DMY") // Original
replace eproc = . if mi(nit_date)


* Note the year eproc started in each package's state
gen eproc_start_year = .
replace eproc_start_year = 2004 if state == "Andhra Pradesh"
replace eproc_start_year = 2011 if state == "Arunachal Pradesh"
replace eproc_start_year = 2004 if state == "Assam"
replace eproc_start_year = 2010 if state == "Bihar"
replace eproc_start_year = 2006 if state == "Chhattisgarh"
replace eproc_start_year = 2006 if state == "Gujarat"
replace eproc_start_year = 2007 if state == "Haryana"
replace eproc_start_year = 2010 if state == "Himachal Pradesh"
replace eproc_start_year = 2011 if state == "Jammu And Kashmir"
replace eproc_start_year = 2010 if state == "Jharkhand"
replace eproc_start_year = 2008 if state == "Karnataka"
replace eproc_start_year = 2011 if state == "Kerala"
replace eproc_start_year = 2007 if state == "Madhya Pradesh"
replace eproc_start_year = 2010 if state == "Maharashtra"
replace eproc_start_year = 2010 if state == "Manipur"
replace eproc_start_year = 2011 if state == "Meghalaya"
replace eproc_start_year = 2012 if state == "Mizoram"
replace eproc_start_year = 2011 if state == "Nagaland"
replace eproc_start_year = 2008 if state == "Orissa"
replace eproc_start_year = 2011 if state == "Punjab"
replace eproc_start_year = 2009 if state == "Rajasthan"
replace eproc_start_year = 2011 if state == "Sikkim"
replace eproc_start_year = 2013 if state == "Tamilnadu"
replace eproc_start_year = 2010 if state == "Tripura"
replace eproc_start_year = 2010 if state == "Uttar Pradesh"
replace eproc_start_year = 2011 if state == "Uttarakhand"
replace eproc_start_year = 2009 if state == "West Bengal"


* Based on the above values, mark packages sanctioned during a year eproc was present
gen eproc_syear = (sanction_year >= eproc_start_year)
replace eproc_syear = . if mi(sanction_year)

* Based on the above values, mark contracts tendered during a year eproc was present
gen eproc_nyear = (nit_year >= eproc_start_year)
replace eproc_nyear = . if mi(nit_year)

* Create contract year variable
gen contract_year = year(contract_date)

* Based on the above values, create lags and leads variables
gen Lag3 = (nit_year >= eproc_start_year + 3)
replace Lag3 = . if mi(nit_year) | mi(eproc_start_year)
gen Lag2 = (nit_year == eproc_start_year + 2)
replace Lag2 = . if mi(nit_year) | mi(eproc_start_year)
gen Lag1 = (nit_year == eproc_start_year + 1)
replace Lag1 = . if mi(nit_year) | mi(eproc_start_year)
gen Y0 = (nit_year == eproc_start_year)
replace Y0 = . if mi(nit_year) | mi(eproc_start_year)
gen Lead1 = (nit_year == eproc_start_year - 1)
replace Lead1 = . if mi(nit_year) | mi(eproc_start_year)
gen Lead2 = (nit_year == eproc_start_year - 2)
replace Lead2 = . if mi(nit_year) | mi(eproc_start_year)
gen Lead3 = (nit_year <= eproc_start_year - 3)
replace Lead3 = . if mi(nit_year) | mi(eproc_start_year)

* Create contractor IDs for across dataset (contractor ID is for within state)
gen contractor_id_temp = state + string(contractor_id) if !mi(contractor_id)
encode contractor_id_temp, g(contractor_id_at_large)
drop contractor_id_temp

* Create company IDs based on strings (likely messy)
egen company_id_at_large = group(company)

* Note award delay in years and what percent of those year eproc was present
gen award_delay = contract_year-sanction_year
gen award_delay_percent_eproc = (contract_year - eproc_start_year) / award_delay
replace award_delay_percent_eproc = 0 if award_delay_percent_eproc < 0
replace award_delay_percent_eproc = 1 if award_delay_percent_eproc > 1

* Note number of bids disqualified
gen disqualified_bids = total_bids - qualified_bids

* Create dummies for minimum numbers of total and qualified
gen tot_al2 = (total_bids > 1) if !mi(total_bids)
gen tot_al3 = (total_bids > 2) if !mi(total_bids)
gen tot_al4 = (total_bids > 3) if !mi(total_bids)
gen tot_al5 = (total_bids > 4) if !mi(total_bids)
gen qual_al2 = (qualified_bids > 1) if !mi(qualified_bids)
gen qual_al3 = (qualified_bids > 2) if !mi(qualified_bids)
gen qual_al4 = (qualified_bids > 3) if !mi(qualified_bids)
gen qual_al5 = (qualified_bids > 4) if !mi(qualified_bids)

* Mark if all but one bid was disqualified
gen all_but_1_disqual = ( (qualified_bids == 1) & (total_bids > 1) ) if !mi(total_bids) & !mi(qualified_bids)

* Create share disqualified var and theoretical all but one disqualified share
gen share_disqualified = disqualified_bids / total_bids
gen all_but_1_disqual_share = (total_bids - 1) / total_bids

* Mark contract if awarded after eproc first started in any state (24Mar2004)
gen post_eproc = (nit_date >= date("24Mar2004", "DMY"))

* Mark as a new winner if contractor is winning for the first time and had never won before eproc began in any state, set missing before eproc began in any state 
bysort contractor_id_at_large (nit_date): gen new_winner = (_n == 1)
replace new_winner = . if !post_eproc 

* Contractor's first year and dummies for contractor present in each year
bysort contractor_id_at_large (nit_date): gen contractor_first_year = year(nit_date[1]) if !mi(contractor_id_at_large)
forvalues lstnm = 0/7 {
	gen contractor_present_in_0`lstnm' = contractor_first_year <= 200`lstnm' if year(nit_date) > 200`lstnm'
}

* Note number of contractors present in each package and how many contracts each contractor has in each package
bysort package sanction_year district_id contractor_id_at_large: gen unique_contractor = _n == 1
by package sanction_year district_id: egen contractors_in_package = count(unique_contractor)
by package sanction_year district_id contractor_id_at_large: gen contractors_contract_in_package = _N
drop unique_contractor

* Mark contract if awarded after eproc began anywhere and went to contractor normally seen in another state before eproc began anywhere
bysort company_id_at_large post_eproc: egen company_home_state = mode(state) if !post_eproc
bysort company_id_at_large (post_eproc): replace company_home_state = company_home_state[1]
gen out_of_state = (state != company_home_state) 
replace out_of_state = 0 if mi(company_home_state)
replace out_of_state = . if !post_eproc

* Mark contract if awarded after eproc began anywhere and went to contractor normally seen in another district before eproc began anywhere
bysort contractor_id_at_large post_eproc: egen contractor_home_district = mode(district_id) if post_eproc == 0
bysort contractor_id_at_large (post_eproc): replace contractor_home_district = contractor_home_district[1]
gen out_of_district = (district_id != contractor_home_district) if !mi(district_id) & !mi(contractor_home_district) & !(nit_date <= date("24Mar2004", "DMY"))

* Mark contract if awarded to contractor not seen before eproc started in state
gen contractor_only_eproc = contractor_first_year >= eproc_start_year if !mi(contractor_first_year) & !mi(eproc_start_year)

* Create opposite of out_of_district
gen same_district = abs(out_of_district - 1)

* Gen unique variable so that resshape works
gen unique = _n

* Reshape long for list of all inspections and and drop all blank observations
reshape long monitor_name quality_grade completion_status_at_inspect inspection_date, i(unique)
drop if mi(inspection_date) & _j != 1

* Record worst quality grade and whether all projects were complete at all inspections
bysort sanction_year package district_id: egen worst_quality_grade = min(quality_grade)
by sanction_year package district_id: egen all_complete_at_insp = min(completion_status_at_inspect)

* Drop all but first inspection and rename as first inspection vars
gsort sanction_year package district_id inspection_date quality_grade -completion_status_at_inspect
by sanction_year package district_id: gen first_monitor = monitor_name[1]
by sanction_year package district_id: gen first_quality_grade = quality_grade[1]
by sanction_year package district_id: gen complete_at_first_insp = completion_status_at_inspect[1]
by sanction_year package district_id: gen first_inspection_date = inspection_date[1]
bysort sanction_year package district_id (contract_date): gen first_contract_date = contract_date[1]
gen work_days_at_first_inspection = first_inspection_date - first_contract_date
replace first_quality_grade = . if work_days_at_first_inspection < 0
replace worst_quality_grade = . if work_days_at_first_inspection < 0
replace complete_at_first_insp = . if complete_at_first_insp < 0

* Drop all but one obervation per contract (there are multiple after reshape)
drop if _j != 1

* Drop variables not needed after reshape 
drop _j unique monitor_name quality_grade completion_status_at_inspect inspection_date

* Create monitor IDs
encode first_monitor, gen(monitor_id)

* Create first inspection year IDs
gen first_insp_year = year(first_inspection_date)

* Create variable equal to share of all but one bid
gen share_all_but_1 = (total_bids - 1) / total_bids

* Create marker for complete contracts and measure of how long contractors are given to complete projects and number of days after due date completion was recorded
gen time_overrun_ratio = (days_late + completion_period) / completion_period
gen late = time_overrun_ratio > 1 if !mi(time_overrun_ratio)
gen late_1pt5x = time_overrun_ratio > 1.5 if !mi(time_overrun_ratio)
gen late_2x = time_overrun_ratio > 2 if !mi(time_overrun_ratio)

* Create new construction delay vars
gen constr_lateness = days_late
replace constr_lateness = 0 if constr_lateness < 0
gen early = (days_late < 0) if !mi(days_late)
gen days_late_negszero = days_late
replace days_late_negszero = 0 if days_late < 0 & !mi(days_late)

* Add corruption, GDP, internet, literacy measures
merge state_id using "Data/States/corruption_measures.dta", sort nokeep uniqusing
drop state_name _merge
merge state_id using "Data/States/stateGDPpercap.dta", sort nokeep uniqusing
drop state_name _merge
merge state_id using "Data/States/internet.dta", sort nokeep uniqusing
drop state_name _merge
merge state_id using "Data/States/literacy2001.dta", sort nokeep uniqusing
drop state_name _merge



***********************
** Contract Level Dataset
***********************

preserve

gen payment_on_completed = payment if contract_complete
gen work_value_on_completed = work_value if contract_complete

* Gen overruns and ratios at contract level
gen contract_overrun = contract_value - estimated_cost
gen contract_value_ratio = contract_value / estimated_cost
gen payment_overrun = payment_on_completed - estimated_cost
gen payment_ratio = payment_on_completed / estimated_cost
gen percent_roads_late = roads_completed_late / completed_road_count
gen any_overrun = .
replace any_overrun = (contract_overrun > 0) if !mi(contract_overrun)
replace any_overrun = (payment_overrun > 0) if !mi(payment_overrun) & any_overrun != 1

* Gen logs at contract level
gen log_road_length = log(road_length)
gen log_estimated_cost = log(estimated_cost)
gen log_contract_value = log(contract_value)
gen log_contract_overrun = log(contract_overrun)
gen log_payment_on_completed = log(payment_on_completed)
gen log_payment_overrun = log(payment_overrun)
gen log_work_value_on_completed = log(work_value_on_completed)

* Compress and save
compress
save "Coded Dataset - Contract Level.dta", replace

restore

***********************
** Package Level Dataset
***********************

* Collapse data to package level
collapse (max) any_eproc=eproc any_out_of_district=out_of_district ///
	(min) all_new_winner=new_winner all_out_of_state=out_of_state all_out_of_district=out_of_district any_delay=early first_nit_year=nit_year ///
	(sum) contract_value eproc_contracts=eproc completed_contracts=contract_complete new_winners=new_winner /// 
	(mean) completion_period avg_days_late = days_late avg_days_late_negszero = days_late_negszero (count) bid_data=total_bids possibly_new=new_winner, ///
	by(package sanction_year district district_id estimated_cost payment road_length roads_completed_late contractors_in_package work_value ///
	contracts_in_package all_complete_at_insp worst_quality_grade completed_road_count roads_awarded_late first_quality_grade first_inspection_date ///
	first_insp_year complete_at_first_insp first_monitor monitor_id sanctioned_road_count eproc_syear state_id state_syear_id eproc_start_year ///
	first_contract_date corruption* *GDP* pop* *internet literacy2001) fast


* Fix contract value missings adding to 0
replace contract_value = . if contract_value == 0

* Create percent eproc variable
gen percent_eproc = eproc_contracts/contracts_in_package

* Create marker for packages with multiple contracts
gen multiple_contracts = (contracts_in_package > 1)

* Create payment variable that is missing if work is ongoing for any contract
gen payment_on_completed = payment if completed_contracts == contracts_in_package
gen work_value_on_completed = work_value if completed_contracts == contracts_in_package

* Gen overruns and ratios at package level
gen contract_overrun = contract_value - estimated_cost
gen contract_value_ratio = contract_value / estimated_cost
gen payment_overrun = payment_on_completed - estimated_cost
gen payment_ratio = payment_on_completed / estimated_cost
gen payment_overrun_ratio = payment_on_completed / contract_value
gen percent_roads_late = roads_completed_late / completed_road_count
gen any_overrun = .
replace any_overrun = (contract_overrun > 0) if !mi(contract_overrun)
replace any_overrun = (payment_overrun > 0) if !mi(payment_overrun) & any_overrun != 1

* Gen logs at package level
gen log_road_length = log(road_length)
gen log_estimated_cost = log(estimated_cost)
gen log_contract_value = log(contract_value)
gen log_contract_overrun = log(contract_overrun)
gen log_payment_on_completed = log(payment_on_completed)
gen log_payment_overrun = log(payment_overrun)
gen log_work_value_on_completed = log(work_value_on_completed)

* Note first award delay in years and what percent of those year eproc was present
gen first_contract_year = year(first_contract_date)
gen award_delay = first_contract_year-sanction_year
gen award_delay_percent_eproc = (first_contract_year - eproc_start_year) / award_delay
replace award_delay_percent_eproc = 0 if award_delay_percent_eproc < 0
replace award_delay_percent_eproc = 1 if award_delay_percent_eproc > 1

* Gen share new winners
gen share_new_winners = new_winners/possibly_new

* Fix any_delay
replace any_delay = abs(any_delay - 1)

* Create percent roads awarded late
gen percent_roads_awarded_late = roads_awarded_late/sanctioned_road_count

* Lags and Leads
gen Lag3 = (sanction_year >= eproc_start_year + 3)
replace Lag3 = . if mi(sanction_year) | mi(eproc_start_year)
gen Lag2 = (sanction_year == eproc_start_year + 2)
replace Lag2 = . if mi(sanction_year) | mi(eproc_start_year)
gen Lag1 = (sanction_year == eproc_start_year + 1)
replace Lag1 = . if mi(sanction_year) | mi(eproc_start_year)
gen Y0 = (sanction_year == eproc_start_year)
replace Y0 = . if mi(sanction_year) | mi(eproc_start_year)
gen Lead1 = (sanction_year == eproc_start_year - 1)
replace Lead1 = . if mi(sanction_year) | mi(eproc_start_year)
gen Lead2 = (sanction_year == eproc_start_year - 2)
replace Lead2 = . if mi(sanction_year) | mi(eproc_start_year)
gen Lead3 = (sanction_year <= eproc_start_year - 3)
replace Lead3 = . if mi(sanction_year) | mi(eproc_start_year)


* Compress and save
compress
save "Coded Dataset - Package Level.dta", replace

